==> hyades.ies.sdk.3.0.0_20040331_1118.zip: org/eclipse/hyades/uml2sd/trace/loaders/internal/TraceSyncMessageReturn.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.uml2sd.trace.loaders.internal;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.models.trace.TRCFullMethodInvocation;
import org.eclipse.hyades.uml2sd.trace.selection.IDateSelection;
import org.eclipse.hyades.uml2sd.trace.selection.IEObjectSelection;
import org.eclipse.hyades.uml2sd.ui.core.SyncMessageReturn;


/**
 * Here is a message return
 */
public class TraceSyncMessageReturn extends SyncMessageReturn
		implements IDateSelection, ITraceMessage, IEObjectSelection {
	
	public TRCFullMethodInvocation model;

	/**
	 * @see org.eclipse.hyades.uml2sd.trace.selection.IDateSelection#getMeaning()
	 */
	public int getMeaning() {
		return IDateSelection.NOW;
	}
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.selection.IDateSelection#getStartDate()
	 */
	public double getStartDate() {
		return model == null ? 0 : model.getExitTime();
	}
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.selection.IDateSelection#getEndDate()
	 */
	public double getEndDate() {
		return getStartDate();
	}
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.selection.IEObjectSelection#getEObject()
	 */
	public EObject getEObject() {
		return model;
	}
}

==> hyades.ies.sdk.3.0.1_20040922_0955.zip: org/eclipse/hyades/uml2sd/trace/loaders/internal/TraceSyncMessageReturn.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.uml2sd.trace.loaders.internal;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.models.trace.TRCFullMethodInvocation;
import org.eclipse.hyades.uml2sd.trace.selection.IDateSelection;
import org.eclipse.hyades.uml2sd.trace.selection.IEObjectSelection;
import org.eclipse.hyades.uml2sd.ui.core.SyncMessageReturn;


/**
 * Here is a message return
 */
public class TraceSyncMessageReturn extends SyncMessageReturn
		implements IDateSelection, ITraceMessage, IEObjectSelection {
	
	public TRCFullMethodInvocation model;

	/**
	 * @see org.eclipse.hyades.uml2sd.trace.selection.IDateSelection#getMeaning()
	 */
	public int getMeaning() {
		return IDateSelection.NOW;
	}
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.selection.IDateSelection#getStartDate()
	 */
	public double getStartDate() {
		return model == null ? 0 :
			(model.getExitTime() == 0) ?
			(getLastTime()-TraceInteractionUtils.getAbsoluteEntryTime(model.getProcess().getAgent())) :
			model.getExitTime();
	}
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.selection.IDateSelection#getEndDate()
	 */
	public double getEndDate() {
		return getStartDate();
	}
	/**
	 * @see org.eclipse.hyades.uml2sd.trace.selection.IEObjectSelection#getEObject()
	 */
	public EObject getEObject() {
		return model;
	}
}
